<?php
/**
 * The Header: Logo and main menu
 *
 * @package MISSION
 * @since MISSION 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js<?php
	// Class scheme_xxx need in the <html> as context for the <body>!
	echo ' scheme_' . esc_attr( mission_get_theme_option( 'color_scheme' ) );
?>">

<head>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	do_action( 'mission_action_before_body' );
	?>

	<div class="<?php echo esc_attr( apply_filters( 'mission_filter_body_wrap_class', 'body_wrap' ) ); ?>" <?php do_action('mission_action_body_wrap_attributes'); ?>>

		<?php do_action( 'mission_action_before_page_wrap' ); ?>

		<div class="<?php echo esc_attr( apply_filters( 'mission_filter_page_wrap_class', 'page_wrap' ) ); ?>" <?php do_action('mission_action_page_wrap_attributes'); ?>>

			<?php do_action( 'mission_action_page_wrap_start' ); ?>

			<?php
			$mission_full_post_loading = ( mission_is_singular( 'post' ) || mission_is_singular( 'attachment' ) ) && mission_get_value_gp( 'action' ) == 'full_post_loading';
			$mission_prev_post_loading = ( mission_is_singular( 'post' ) || mission_is_singular( 'attachment' ) ) && mission_get_value_gp( 'action' ) == 'prev_post_loading';

			// Don't display the header elements while actions 'full_post_loading' and 'prev_post_loading'
			if ( ! $mission_full_post_loading && ! $mission_prev_post_loading ) {

				// Short links to fast access to the content, sidebar and footer from the keyboard
				?>
				<a class="mission_skip_link skip_to_content_link" href="#content_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'mission_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to content", 'mission' ); ?></a>
				<?php if ( mission_sidebar_present() ) { ?>
				<a class="mission_skip_link skip_to_sidebar_link" href="#sidebar_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'mission_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to sidebar", 'mission' ); ?></a>
				<?php } ?>
				<a class="mission_skip_link skip_to_footer_link" href="#footer_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'mission_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to footer", 'mission' ); ?></a>

				<?php
				do_action( 'mission_action_before_header' );

				// Header
				$mission_header_type = mission_get_theme_option( 'header_type' );
				if ( 'custom' == $mission_header_type && ! mission_is_layouts_available() ) {
					$mission_header_type = 'default';
				}
				get_template_part( apply_filters( 'mission_filter_get_template_part', "templates/header-" . sanitize_file_name( $mission_header_type ) ) );

				// Side menu
				if ( in_array( mission_get_theme_option( 'menu_side' ), array( 'left', 'right' ) ) ) {
					get_template_part( apply_filters( 'mission_filter_get_template_part', 'templates/header-navi-side' ) );
				}

				// Mobile menu
				get_template_part( apply_filters( 'mission_filter_get_template_part', 'templates/header-navi-mobile' ) );

				do_action( 'mission_action_after_header' );

			}
			?>

			<?php do_action( 'mission_action_before_page_content_wrap' ); ?>

			<div class="page_content_wrap<?php
				if ( mission_is_off( mission_get_theme_option( 'remove_margins' ) ) ) {
					if ( empty( $mission_header_type ) ) {
						$mission_header_type = mission_get_theme_option( 'header_type' );
					}
					if ( 'custom' == $mission_header_type && mission_is_layouts_available() ) {
						$mission_header_id = mission_get_custom_header_id();
						if ( $mission_header_id > 0 ) {
							$mission_header_meta = mission_get_custom_layout_meta( $mission_header_id );
							if ( ! empty( $mission_header_meta['margin'] ) ) {
								?> page_content_wrap_custom_header_margin<?php
							}
						}
					}
					$mission_footer_type = mission_get_theme_option( 'footer_type' );
					if ( 'custom' == $mission_footer_type && mission_is_layouts_available() ) {
						$mission_footer_id = mission_get_custom_footer_id();
						if ( $mission_footer_id ) {
							$mission_footer_meta = mission_get_custom_layout_meta( $mission_footer_id );
							if ( ! empty( $mission_footer_meta['margin'] ) ) {
								?> page_content_wrap_custom_footer_margin<?php
							}
						}
					}
				}
				do_action( 'mission_action_page_content_wrap_class', $mission_prev_post_loading );
				?>"<?php
				if ( apply_filters( 'mission_filter_is_prev_post_loading', $mission_prev_post_loading ) ) {
					?> data-single-style="<?php echo esc_attr( mission_get_theme_option( 'single_style' ) ); ?>"<?php
				}
				do_action( 'mission_action_page_content_wrap_data', $mission_prev_post_loading );
			?>>
				<?php
				do_action( 'mission_action_page_content_wrap', $mission_full_post_loading || $mission_prev_post_loading );

				// Single posts banner
				if ( apply_filters( 'mission_filter_single_post_header', mission_is_singular( 'post' ) || mission_is_singular( 'attachment' ) ) ) {
					if ( $mission_prev_post_loading ) {
						if ( mission_get_theme_option( 'posts_navigation_scroll_which_block' ) != 'article' ) {
							do_action( 'mission_action_between_posts' );
						}
					}
					// Single post thumbnail and title
					$mission_path = apply_filters( 'mission_filter_get_template_part', 'templates/single-styles/' . mission_get_theme_option( 'single_style' ) );
					if ( mission_get_file_dir( $mission_path . '.php' ) != '' ) {
						get_template_part( $mission_path );
					}
				}

				// Widgets area above page
				$mission_body_style   = mission_get_theme_option( 'body_style' );
				$mission_widgets_name = mission_get_theme_option( 'widgets_above_page' );
				$mission_show_widgets = ! mission_is_off( $mission_widgets_name ) && is_active_sidebar( $mission_widgets_name );
				if ( $mission_show_widgets ) {
					if ( 'fullscreen' != $mission_body_style ) {
						?>
						<div class="content_wrap">
							<?php
					}
					mission_create_widgets_area( 'widgets_above_page' );
					if ( 'fullscreen' != $mission_body_style ) {
						?>
						</div>
						<?php
					}
				}

				// Content area
				do_action( 'mission_action_before_content_wrap' );
				?>
				<div class="content_wrap<?php echo 'fullscreen' == $mission_body_style ? '_fullscreen' : ''; ?>">

					<?php do_action( 'mission_action_content_wrap_start' ); ?>

					<div class="content">
						<?php
						do_action( 'mission_action_page_content_start' );

						// Skip link anchor to fast access to the content from keyboard
						?>
						<a id="content_skip_link_anchor" class="mission_skip_link_anchor" href="#"></a>
						<?php
						// Single posts banner between prev/next posts
						if ( ( mission_is_singular( 'post' ) || mission_is_singular( 'attachment' ) )
							&& $mission_prev_post_loading 
							&& mission_get_theme_option( 'posts_navigation_scroll_which_block' ) == 'article'
						) {
							do_action( 'mission_action_between_posts' );
						}

						// Widgets area above content
						mission_create_widgets_area( 'widgets_above_content' );

						do_action( 'mission_action_page_content_start_text' );
