<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package MISSION
 * @since MISSION 1.0
 */

$mission_template = apply_filters( 'mission_filter_get_template_part', mission_blog_archive_get_template() );

if ( ! empty( $mission_template ) && 'index' != $mission_template ) {

	get_template_part( $mission_template );

} else {

	mission_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$mission_stickies   = is_home()
								|| ( in_array( mission_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) mission_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$mission_post_type  = mission_get_theme_option( 'post_type' );
		$mission_args       = array(
								'blog_style'     => mission_get_theme_option( 'blog_style' ),
								'post_type'      => $mission_post_type,
								'taxonomy'       => mission_get_post_type_taxonomy( $mission_post_type ),
								'parent_cat'     => mission_get_theme_option( 'parent_cat' ),
								'posts_per_page' => mission_get_theme_option( 'posts_per_page' ),
								'sticky'         => mission_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $mission_stickies )
															&& count( $mission_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		mission_blog_archive_start();

		do_action( 'mission_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'mission_action_before_page_author' );
			get_template_part( apply_filters( 'mission_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'mission_action_after_page_author' );
		}

		if ( mission_get_theme_option( 'show_filters' ) ) {
			do_action( 'mission_action_before_page_filters' );
			mission_show_filters( $mission_args );
			do_action( 'mission_action_after_page_filters' );
		} else {
			do_action( 'mission_action_before_page_posts' );
			mission_show_posts( array_merge( $mission_args, array( 'cat' => $mission_args['parent_cat'] ) ) );
			do_action( 'mission_action_after_page_posts' );
		}

		do_action( 'mission_action_blog_archive_end' );

		mission_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'mission_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'mission_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
