<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package MISSION
 * @since MISSION 1.0
 */

if ( mission_sidebar_present() ) {
	
	$mission_sidebar_type = mission_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $mission_sidebar_type && ! mission_is_layouts_available() ) {
		$mission_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $mission_sidebar_type ) {
		// Default sidebar with widgets
		$mission_sidebar_name = mission_get_theme_option( 'sidebar_widgets' );
		mission_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $mission_sidebar_name ) ) {
			dynamic_sidebar( $mission_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$mission_sidebar_id = mission_get_custom_sidebar_id();
		do_action( 'mission_action_show_layout', $mission_sidebar_id );
	}
	$mission_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $mission_out ) ) {
		$mission_sidebar_position    = mission_get_theme_option( 'sidebar_position' );
		$mission_sidebar_position_ss = mission_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $mission_sidebar_position );
			echo ' sidebar_' . esc_attr( $mission_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $mission_sidebar_type );

			$mission_sidebar_scheme = apply_filters( 'mission_filter_sidebar_scheme', mission_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $mission_sidebar_scheme ) && ! mission_is_inherit( $mission_sidebar_scheme ) && 'custom' != $mission_sidebar_type ) {
				echo ' scheme_' . esc_attr( $mission_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="mission_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'mission_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $mission_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$mission_title = apply_filters( 'mission_filter_sidebar_control_title', 'float' == $mission_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'mission' ) : '' );
				$mission_text  = apply_filters( 'mission_filter_sidebar_control_text', 'above' == $mission_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'mission' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $mission_title ); ?>"><?php echo esc_html( $mission_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'mission_action_before_sidebar', 'sidebar' );
				mission_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $mission_out ) );
				do_action( 'mission_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'mission_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
