<?php
/**
 * Skin Setup
 *
 * @package MISSION
 * @since MISSION 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'mission_theme_defaults' ) ) {
	function mission_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 130,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0,
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( empty( $value ) && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'mission_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'mission_skin_setup', 1 );
	function mission_skin_setup() {

		$GLOBALS['MISSION_STORAGE'] = array_merge( $GLOBALS['MISSION_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-themerex',

			'theme_doc_url'       => '//mission.themerex.net/doc',

			'theme_demofiles_url' => '//demofiles.themerex.net/mission/',
			
			'theme_rate_url'      => '//themeforest.net/download',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

            'theme_download_url'  => '//themeforest.net/user/themerex/portfolio',            // ThemeREX

            'theme_video_url'     => '//www.youtube.com/channel/UCnFisBimrK2aIE-hnY70kCA',   // ThemeREX

            'theme_privacy_url'   => '//themerex.net/privacy-policy/',                       // ThemeREX

            'portfolio_url'       => '//themeforest.net/user/themerex/portfolio',            // ThemeREX

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}


// Add/remove/change Theme Settings
if ( ! function_exists( 'mission_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'mission_skin_setup_settings', 1 );
	function mission_skin_setup_settings() {
		// Example: enable (true) / disable (false) thumbs in the prev/next navigation
		mission_storage_set_array( 'settings', 'thumbs_in_navigation', false );
        mission_storage_set_array2( 'required_plugins', 'instagram-feed', 'install', true);
        mission_storage_set_array2( 'required_plugins', 'the-events-calendar', 'install', true);
	}
}


// Enqueue extra styles for frontend
if ( ! function_exists( 'mission_trx_addons_extra_styles' ) ) {
    add_action( 'wp_enqueue_scripts', 'mission_trx_addons_extra_styles', 1160 );
    function mission_trx_addons_extra_styles() {
        $mission_url = mission_get_file_url( 'extra-styles.css' );
        if ( '' != $mission_url ) {
            wp_enqueue_style( 'mission-trx-addons-extra-styles', $mission_url, array(), null );
        }
    }
}


//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'mission_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'mission_skin_setup_fonts', 1 );
	function mission_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		mission_storage_set(
			'load_fonts', array(
				array(
					'name'   => 'Nunito',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'ital,wght@0,300;0,400;0,600;0,700;1,300;1,400;1,600;1,700'
				),
				array(
					'name'   => 'Kumbh Sans',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'wght@300;400;500;600;700'
				),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		mission_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => basekit_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'mission' );

		mission_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'mission' ) ),
					'font-family'     => 'Nunito,sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.62em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0.1px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.57em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'mission' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '3.353em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.053em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-1.1px',
					'margin-top'      => '1.23em',
					'margin-bottom'   => '0.3em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '2.765em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.064em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.9px',
					'margin-top'      => '0.89em',
					'margin-bottom'   => '0.33em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '2.059em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.086em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.35px',
					'margin-top'      => '1.29em',
					'margin-bottom'   => '0.52em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '1.647em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.214em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.28px',
					'margin-top'      => '1.55em',
					'margin-bottom'   => '0.5em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '1.333em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.412em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.24px',
					'margin-top'      => '1.5em',
					'margin-bottom'   => '0.56em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '1.056em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.118em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.19px',
					'margin-top'      => '1.75em',
					'margin-bottom'   => '0.8em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '1.7em',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-0.3px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '13px',
					'font-weight'     => '700',
					'font-style'      => 'normal',
					'line-height'     => '21px',
					'text-decoration' => 'none',
					'text-transform'  => 'uppercase',
					'letter-spacing'  => '1.3px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'mission' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '16px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'mission' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '14px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'mission' ) ),
					'font-family'     => '"Kumbh Sans",sans-serif',
					'font-size'       => '17px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'mission' ) ),
					'font-family'     => 'Nunito,sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'mission' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'mission' ) ),
					'font-family'     => 'Nunito,sans-serif',
				),
			)
		);

		// Font presets
		mission_storage_set(
			'font_presets', array(
				'karla' => array(
								'title'  => esc_html__( 'Karla', 'mission' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Dancing Script',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
													// Google font
													array(
														'name'   => 'Sansita Swashed',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Dancing Script",fantasy',
														'font-size'       => '1.25rem',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
														'font-size'       => '4em',
													),
													'h2'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h3'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h4'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h5'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h6'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'logo'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'button'  => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'submenu' => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
												),
							),
				'roboto' => array(
								'title'  => esc_html__( 'Roboto', 'mission' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Noto Sans JP',
														'family' => 'serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
													// Google font
													array(
														'name'   => 'Merriweather',
														'family' => 'sans-serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Noto Sans JP",serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
												),
							),
				'garamond' => array(
								'title'  => esc_html__( 'Garamond', 'mission' ),
								'load_fonts' => array(
													// Adobe font
													array(
														'name'   => 'Europe',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
													// Adobe font
													array(
														'name'   => 'Sofia Pro',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Sofia Pro",sans-serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Europe,sans-serif',
													),
												),
							),
			)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'mission_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'mission_skin_setup_schemes', 1 );
	function mission_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		mission_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'mission' ),
					'description' => esc_html__( 'Colors of the main content area', 'mission' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'mission' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'mission' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'mission' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'mission' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'mission' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'mission' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'mission' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'mission' ),
				),
			)
		);

		mission_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'mission' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'mission' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'mission' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'mission' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'mission' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'mission' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'mission' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'mission' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'mission' ),
					'description' => esc_html__( 'Color of the text inside this block', 'mission' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'mission' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'mission' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'mission' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'mission' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'mission' ),
					'description' => esc_html__( 'Color of the links inside this block', 'mission' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'mission' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'mission' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'mission' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'mission' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'mission' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'mission' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'mission' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'mission' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'mission' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'mission' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'mission' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F7F2F0', //ok +
					'bd_color'         => '#E3D6D3', //ok +

					// Text and links colors
					'text'             => '#7C6D66', //ok +
					'text_light'       => '#988F8A', //ok +
					'text_dark'        => '#240C00', //ok +
					'text_link'        => '#3F292B', //ok +
					'text_hover'       => '#4E383A', //ok +
					'text_link2'       => '#D1AB42', //ok +
					'text_hover2'      => '#CCA331', //ok +
					'text_link3'       => '#A37B73', //ok +
					'text_hover3'      => '#9D746C', //ok +

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF', //ok +
					'alter_bg_hover'   => '#F2E8E6', //ok +
					'alter_bd_color'   => '#E3D6D3', //ok +
					'alter_bd_hover'   => '#B8ABA8', //ok +
					'alter_text'       => '#7C6D66', //ok +
					'alter_light'      => '#988F8A', //ok +
					'alter_dark'       => '#240C00', //ok +
					'alter_link'       => '#3F292B', //ok +
					'alter_hover'      => '#4E383A', //ok +
					'alter_link2'      => '#D1AB42', //ok +
					'alter_hover2'     => '#CCA331', //ok +
					'alter_link3'      => '#A37B73', //ok +
					'alter_hover3'     => '#9D746C', //ok +

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#342A25', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#CAC2C0', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#F8F2F1', //ok +
					'extra_link'       => '#3F292B', //ok +
					'extra_hover'      => '#FFFFFF', //ok +
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#E3D6D3', //ok +
					'input_bd_hover'   => '#B8ABA8', //ok +
					'input_text'       => '#7C6D66', //ok +
					'input_light'      => '#988F8A', //ok +
					'input_dark'       => '#240C00', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#240C00', //ok +
					'inverse_link'     => '#FFFFFF', //ok +
					'inverse_hover'    => '#FFFFFF', //ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'mission' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#130701', //ok +
					'bd_color'         => '#5A524E', //ok +

					// Text and links colors
					'text'             => '#CAC2C0', //ok +
					'text_light'       => '#958F8C', //ok +
					'text_dark'        => '#F8F2F1', //ok +
					'text_link'        => '#3F292B', //ok +
					'text_hover'       => '#4E383A', //ok +
					'text_link2'       => '#D1AB42', //ok +
					'text_hover2'      => '#CCA331', //ok +
					'text_link3'       => '#A37B73', //ok +
					'text_hover3'      => '#9D746C', //ok +

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#1C110B', //ok +
					'alter_bg_hover'   => '#2B201B', //ok +
					'alter_bd_color'   => '#5A524E', //ok +
					'alter_bd_hover'   => '#898380', //ok +
					'alter_text'       => '#CAC2C0', //ok +
					'alter_light'      => '#958F8C', //ok +
					'alter_dark'       => '#F8F2F1', //ok +
					'alter_link'       => '#3F292B', //ok +
					'alter_hover'      => '#4E383A', //ok +
					'alter_link2'      => '#D1AB42', //ok +
					'alter_hover2'     => '#CCA331', //ok +
					'alter_link3'      => '#A37B73', //ok +
					'alter_hover3'     => '#9D746C', //ok +

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#342A25', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#313131',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#CAC2C0', //ok +
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#FFFFFF', //ok +
					'extra_link'       => '#3F292B', //ok +
					'extra_hover'      => '#FFFFFF', //ok +
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent', //ok
					'input_bg_hover'   => '#transparent', //ok
					'input_bd_color'   => '#5A524E', //ok +
					'input_bd_hover'   => '#898380', //ok +
					'input_text'       => '#CAC2C0', //ok +
					'input_light'      => '#CAC2C0', //ok +
					'input_dark'       => '#FFFFFF', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#F8F2F1', //ok +
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#240C00', //ok +
					'inverse_link'     => '#FFFFFF', //ok
					'inverse_hover'    => '#240C00', //ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

            // Color scheme: 'light'
            'light' => array(
                'title'    => esc_html__( 'Light', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok +
                    'bd_color'         => '#E3D6D3', //ok +

                    // Text and links colors
                    'text'             => '#7C6D66', //ok +
                    'text_light'       => '#988F8A', //ok +
                    'text_dark'        => '#240C00', //ok +
                    'text_link'        => '#3F292B', //ok +
                    'text_hover'       => '#4E383A', //ok +
                    'text_link2'       => '#D1AB42', //ok +
                    'text_hover2'      => '#CCA331', //ok +
                    'text_link3'       => '#A37B73', //ok +
                    'text_hover3'      => '#9D746C', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F7F2F0', //ok +
                    'alter_bg_hover'   => '#EEECEC', //ok
                    'alter_bd_color'   => '#E3D6D3', //ok +
                    'alter_bd_hover'   => '#B8ABA8', //ok +
                    'alter_text'       => '#7C6D66', //ok +
                    'alter_light'      => '#988F8A', //ok +
                    'alter_dark'       => '#240C00', //ok +
                    'alter_link'       => '#3F292B', //ok +
                    'alter_hover'      => '#4E383A', //ok +
                    'alter_link2'      => '#D1AB42', //ok +
                    'alter_hover2'     => '#CCA331', //ok +
                    'alter_link3'      => '#A37B73', //ok +
                    'alter_hover3'     => '#9D746C', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#342A25', //ok +
                    'extra_bg_hover'   => '#3f3d47',
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#CAC2C0', //ok +
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#F8F2F1', //ok +
                    'extra_link'       => '#3F292B', //ok +
                    'extra_hover'      => '#FFFFFF', //ok +
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#E3D6D3', //ok +
                    'input_bd_hover'   => '#B8ABA8', //ok +
                    'input_text'       => '#7C6D66', //ok +
                    'input_light'      => '#988F8A', //ok +
                    'input_dark'       => '#240C00', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#240C00', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),


            // Color scheme: 'yellow'
            'yellow' => array(
                'title'    => esc_html__( 'Yellow', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#F9F5EA', //ok +
                    'bd_color'         => '#E8E2D4', //ok +

                    // Text and links colors
                    'text'             => '#9D9087', //ok +
                    'text_light'       => '#988F8A', //ok +
                    'text_dark'        => '#441A05', //ok +
                    'text_link'        => '#DB9E30', //ok +
                    'text_hover'       => '#D29320', //ok +
                    'text_link2'       => '#57A68F', //ok +
                    'text_hover2'      => '#459880', //ok +
                    'text_link3'       => '#E95823', //ok +
                    'text_hover3'      => '#D84A16', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#FFFFFF', //ok +
                    'alter_bg_hover'   => '#F6F1E4', //ok +
                    'alter_bd_color'   => '#E8E2D4', //ok +
                    'alter_bd_hover'   => '#D1CBBE', //ok +
                    'alter_text'       => '#9D9087', //ok +
                    'alter_light'      => '#988F8A', //ok +
                    'alter_dark'       => '#441A05', //ok +
                    'alter_link'       => '#DB9E30', //ok +
                    'alter_hover'      => '#D29320', //ok +
                    'alter_link2'      => '#57A68F', //ok +
                    'alter_hover2'     => '#459880', //ok +
                    'alter_link3'      => '#E95823', //ok +
                    'alter_hover3'     => '#D84A16', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#2C2A28', //ok +
                    'extra_bg_hover'   => '#1B1918', //+
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#CAC2C0', //ok +
                    'extra_light'      => '#958F8C', //+
                    'extra_dark'       => '#FFFFFF', //ok +
                    'extra_link'       => '#DB9E30', //ok +
                    'extra_hover'      => '#FFFFFF', //ok +
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#E8E2D4', //ok +
                    'input_bd_hover'   => '#D1CBBE', //ok +
                    'input_text'       => '#9D9087', //ok +
                    'input_light'      => '#988F8A', //ok +
                    'input_dark'       => '#441A05', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#441A05', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'dark'
            'yellow-dark'    => array(
                'title'    => esc_html__( 'Yellow - Dark', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#0A0806', //ok +
                    'bd_color'         => '#282624', //ok +

                    // Text and links colors
                    'text'             => '#CAC2C0', //ok +
                    'text_light'       => '#958F8C', //ok +
                    'text_dark'        => '#FFFFFF', //ok +
                    'text_link'        => '#DB9E30', //ok +
                    'text_hover'       => '#D29320', //ok +
                    'text_link2'       => '#57A68F', //ok +
                    'text_hover2'      => '#459880', //ok +
                    'text_link3'       => '#E95823', //ok +
                    'text_hover3'      => '#D84A16', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#14100D', //ok +
                    'alter_bg_hover'   => '#1A1918', //ok +
                    'alter_bd_color'   => '#282624', //ok +
                    'alter_bd_hover'   => '#3B3938', //ok +
                    'alter_text'       => '#CAC2C0', //ok +
                    'alter_light'      => '#958F8C', //ok +
                    'alter_dark'       => '#FFFFFF', //ok +
                    'alter_link'       => '#DB9E30', //ok +
                    'alter_hover'      => '#D29320', //ok +
                    'alter_link2'      => '#57A68F', //ok +
                    'alter_hover2'     => '#459880', //ok +
                    'alter_link3'      => '#E95823', //ok +
                    'alter_hover3'     => '#D84A16', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#2C2A28', //ok +
                    'extra_bg_hover'   => '#1B1918', //+
                    'extra_bd_color'   => '#282624', //+
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#CAC2C0', //ok +
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok +
                    'extra_link'       => '#DB9E30', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => '#transparent', //ok
                    'input_bg_hover'   => '#transparent', //ok
                    'input_bd_color'   => '#282624', //ok +
                    'input_bd_hover'   => '#3B3938', //ok +
                    'input_text'       => '#CAC2C0', //ok +
                    'input_light'      => '#CAC2C0', //ok +
                    'input_dark'       => '#FFFFFF', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#e36650',
                    'inverse_bd_hover' => '#cb5b47',
                    'inverse_text'     => '#FFFFFF', //ok +
                    'inverse_light'    => '#6f6f6f',
                    'inverse_dark'     => '#441A05', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#441A05', //ok +

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'light'
            'yellow-light' => array(
                'title'    => esc_html__( 'Yellow - Light', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok +
                    'bd_color'         => '#E8E2D4', //ok +

                    // Text and links colors
                    'text'             => '#9D9087', //ok +
                    'text_light'       => '#988F8A', //ok +
                    'text_dark'        => '#441A05', //ok +
                    'text_link'        => '#DB9E30', //ok +
                    'text_hover'       => '#D29320', //ok +
                    'text_link2'       => '#57A68F', //ok +
                    'text_hover2'      => '#459880', //ok +
                    'text_link3'       => '#E95823', //ok +
                    'text_hover3'      => '#D84A16', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F9F5EA', //ok +
                    'alter_bg_hover'   => '#EEECEC', //ok +
                    'alter_bd_color'   => '#E8E2D4', //ok +
                    'alter_bd_hover'   => '#D1CBBE', //ok +
                    'alter_text'       => '#9D9087', //ok +
                    'alter_light'      => '#988F8A', //ok +
                    'alter_dark'       => '#441A05', //ok +
                    'alter_link'       => '#DB9E30', //ok +
                    'alter_hover'      => '#D29320', //ok +
                    'alter_link2'      => '#57A68F', //ok +
                    'alter_hover2'     => '#459880', //ok +
                    'alter_link3'      => '#E95823', //ok +
                    'alter_hover3'     => '#D84A16', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#2C2A28', //ok +
                    'extra_bg_hover'   => '#1B1918', //+
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#CAC2C0', //ok +
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok +
                    'extra_link'       => '#DB9E30', //ok +
                    'extra_hover'      => '#FFFFFF', //ok +
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#E8E2D4', //ok +
                    'input_bd_hover'   => '#D1CBBE', //ok +
                    'input_text'       => '#9D9087', //ok +
                    'input_light'      => '#988F8A', //ok +
                    'input_dark'       => '#441A05', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#441A05', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),


            // Color scheme: 'orange'
            'orange' => array(
                'title'    => esc_html__( 'Orange', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#F6F6F6', //ok +
                    'bd_color'         => '#DCDCDC', //ok +

                    // Text and links colors
                    'text'             => '#6E6E6E', //ok +
                    'text_light'       => '#9D9D9D', //ok +
                    'text_dark'        => '#1A1A1A', //ok +
                    'text_link'        => '#FB6602', //ok +
                    'text_hover'       => '#FF7519', //ok +
                    'text_link2'       => '#555555', //ok +
                    'text_hover2'      => '#4A4A4A', //ok +
                    'text_link3'       => '#F6A705', //ok +
                    'text_hover3'      => '#F8B223', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#FFFFFF', //ok +
                    'alter_bg_hover'   => '#ECECEC', //ok +
                    'alter_bd_color'   => '#DCDCDC', //ok +
                    'alter_bd_hover'   => '#C8C8C8', //ok +
                    'alter_text'       => '#6E6E6E', //ok +
                    'alter_light'      => '#9D9D9D', //ok +
                    'alter_dark'       => '#1A1A1A', //ok +
                    'alter_link'       => '#FB6602', //ok +
                    'alter_hover'      => '#FF7519', //ok +
                    'alter_link2'      => '#555555', //ok +
                    'alter_hover2'     => '#4A4A4A', //ok +
                    'alter_link3'      => '#F6A705', //ok +
                    'alter_hover3'     => '#F8B223', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#958F8C', //
                    'extra_dark'       => '#FFFFFF', //ok +
                    'extra_link'       => '#FB6602', //ok +
                    'extra_hover'      => '#FFFFFF', //ok +
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok +
                    'input_bd_hover'   => '#C8C8C8', //ok +
                    'input_text'       => '#6E6E6E', //ok +
                    'input_light'      => '#9D9D9D', //ok +
                    'input_dark'       => '#1A1A1A', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'dark'
            'orange-dark'    => array(
                'title'    => esc_html__( 'Orange - Dark', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#111111', //ok +
                    'bd_color'         => '#4C4C4C', //ok +

                    // Text and links colors
                    'text'             => '#E1E1E1', //ok +
                    'text_light'       => '#C2C2C2', //ok +
                    'text_dark'        => '#FFFFFF', //ok +
                    'text_link'        => '#FB6602', //ok +
                    'text_hover'       => '#FF7519', //ok +
                    'text_link2'       => '#555555', //ok +
                    'text_hover2'      => '#4A4A4A', //ok +
                    'text_link3'       => '#F6A705', //ok +
                    'text_hover3'      => '#F8B223', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#282828', //ok +
                    'alter_bg_hover'   => '#343434', //ok +
                    'alter_bd_color'   => '#4C4C4C', //ok +
                    'alter_bd_hover'   => '#707070', //ok +
                    'alter_text'       => '#E1E1E1', //ok +
                    'alter_light'      => '#C2C2C2', //ok +
                    'alter_dark'       => '#FFFFFF', //ok
                    'alter_link'       => '#FB6602', //ok +
                    'alter_hover'      => '#FF7519', //ok +
                    'alter_link2'      => '#555555', //ok +
                    'alter_hover2'     => '#4A4A4A', //ok +
                    'alter_link3'      => '#F6A705', //ok +
                    'alter_hover3'     => '#F8B223', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#4C4C4C', // +
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#C2C2C2', // +
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#FB6602', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => '#transparent', //ok
                    'input_bg_hover'   => '#transparent', //ok
                    'input_bd_color'   => '#4C4C4C', //ok +
                    'input_bd_hover'   => '#707070', //ok +
                    'input_text'       => '#E1E1E1', //ok +
                    'input_light'      => '#C2C2C2', //ok +
                    'input_dark'       => '#FFFFFF', //ok

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#e36650',
                    'inverse_bd_hover' => '#cb5b47',
                    'inverse_text'     => '#FFFFFF', //ok
                    'inverse_light'    => '#6f6f6f',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#1A1A1A', //ok +

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'light'
            'orange-light' => array(
                'title'    => esc_html__( 'Orange - Light', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok +
                    'bd_color'         => '#DCDCDC', //ok +

                    // Text and links colors
                    'text'             => '#6E6E6E', //ok +
                    'text_light'       => '#9D9D9D', //ok +
                    'text_dark'        => '#1A1A1A', //ok +
                    'text_link'        => '#FB6602', //ok +
                    'text_hover'       => '#FF7519', //ok +
                    'text_link2'       => '#555555', //ok +
                    'text_hover2'      => '#4A4A4A', //ok +
                    'text_link3'       => '#F6A705', //ok +
                    'text_hover3'      => '#F8B223', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F6F6F6', //ok +
                    'alter_bg_hover'   => '#ECECEC', //ok +
                    'alter_bd_color'   => '#DCDCDC', //ok +
                    'alter_bd_hover'   => '#C8C8C8', //ok +
                    'alter_text'       => '#6E6E6E', //ok +
                    'alter_light'      => '#9D9D9D', //ok +
                    'alter_dark'       => '#1A1A1A', //ok +
                    'alter_link'       => '#FB6602', //ok +
                    'alter_hover'      => '#FF7519', //ok +
                    'alter_link2'      => '#555555', //ok +
                    'alter_hover2'     => '#4A4A4A', //ok +
                    'alter_link3'      => '#F6A705', //ok +
                    'alter_hover3'     => '#F8B223', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#FB6602', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok +
                    'input_bd_hover'   => '#C8C8C8', //ok +
                    'input_text'       => '#6E6E6E', //ok +
                    'input_light'      => '#9D9D9D', //ok +
                    'input_dark'       => '#1A1A1A', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),


            // Color scheme: 'purple'
            'purple' => array(
                'title'    => esc_html__( 'Purple', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#F6F6F6', //ok +
                    'bd_color'         => '#DCDCDC', //ok +

                    // Text and links colors
                    'text'             => '#7E8387', //ok +
                    'text_light'       => '#9D9D9D', //ok +
                    'text_dark'        => '#29273D', //ok +
                    'text_link'        => '#6237A0', //ok +
                    'text_hover'       => '#532792', //ok +
                    'text_link2'       => '#DEACF5', //ok +
                    'text_hover2'      => '#D597F2', //ok +
                    'text_link3'       => '#9754CB', //ok +
                    'text_hover3'      => '#8942C1', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#FFFFFF', //ok +
                    'alter_bg_hover'   => '#ECECEC', //ok +
                    'alter_bd_color'   => '#DCDCDC', //ok +
                    'alter_bd_hover'   => '#C8C8C8', //ok +
                    'alter_text'       => '#7E8387', //ok +
                    'alter_light'      => '#9D9D9D', //ok +
                    'alter_dark'       => '#29273D', //ok +
                    'alter_link'       => '#6237A0', //ok +
                    'alter_hover'      => '#532792', //ok +
                    'alter_link2'      => '#DEACF5', //ok +
                    'alter_hover2'     => '#D597F2', //ok +
                    'alter_link3'      => '#9754CB', //ok +
                    'alter_hover3'     => '#8942C1', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#272631', //ok +
                    'extra_bg_hover'   => '#343434', //
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#958F8C', //
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#6237A0', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok
                    'input_bd_hover'   => '#C8C8C8', //ok
                    'input_text'       => '#7E8387', //ok +
                    'input_light'      => '#9D9D9D', //ok
                    'input_dark'       => '#29273D', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#29273D', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'dark'
            'purple-dark'    => array(
                'title'    => esc_html__( 'Purple - Dark', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#171621', //ok +
                    'bd_color'         => '#45454D', //ok +

                    // Text and links colors
                    'text'             => '#E1E1E1', //ok +
                    'text_light'       => '#C2C2C2', //ok +
                    'text_dark'        => '#FFFFFF', //ok +
                    'text_link'        => '#6237A0', //ok +
                    'text_hover'       => '#532792', //ok +
                    'text_link2'       => '#DEACF5', //ok +
                    'text_hover2'      => '#D597F2', //ok +
                    'text_link3'       => '#9754CB', //ok +
                    'text_hover3'      => '#8942C1', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#201F2A', //ok +
                    'alter_bg_hover'   => '#303039', //ok +
                    'alter_bd_color'   => '#45454D', //ok +
                    'alter_bd_hover'   => '#68676F', //ok +
                    'alter_text'       => '#E1E1E1', //ok +
                    'alter_light'      => '#C2C2C2', //ok +
                    'alter_dark'       => '#FFFFFF', //ok +
                    'alter_link'       => '#6237A0', //ok +
                    'alter_hover'      => '#532792', //ok +
                    'alter_link2'      => '#DEACF5', //ok +
                    'alter_hover2'     => '#D597F2', //ok +
                    'alter_link3'      => '#9754CB', //ok +
                    'alter_hover3'     => '#8942C1', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#272631', //ok +
                    'extra_bg_hover'   => '#303039', // +
                    'extra_bd_color'   => '#45454D', // +
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#C2C2C2', //
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#6237A0', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => '#transparent', //ok
                    'input_bg_hover'   => '#transparent', //ok
                    'input_bd_color'   => '#45454D', //ok +
                    'input_bd_hover'   => '#68676F', //ok +
                    'input_text'       => '#E1E1E1', //ok
                    'input_light'      => '#C2C2C2', //ok
                    'input_dark'       => '#FFFFFF', //ok

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#e36650',
                    'inverse_bd_hover' => '#cb5b47',
                    'inverse_text'     => '#FFFFFF', //ok
                    'inverse_light'    => '#6f6f6f',
                    'inverse_dark'     => '#29273D', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#29273D', //ok +

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'light'
            'purple-light' => array(
                'title'    => esc_html__( 'Purple - Light', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok
                    'bd_color'         => '#DCDCDC', //ok

                    // Text and links colors
                    'text'             => '#7E8387', //ok +
                    'text_light'       => '#9D9D9D', //ok
                    'text_dark'        => '#29273D', //ok +
                    'text_link'        => '#6237A0', //ok +
                    'text_hover'       => '#532792', //ok +
                    'text_link2'       => '#DEACF5', //ok +
                    'text_hover2'      => '#D597F2', //ok +
                    'text_link3'       => '#9754CB', //ok +
                    'text_hover3'      => '#8942C1', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F6F6F6', //ok
                    'alter_bg_hover'   => '#ECECEC', //ok
                    'alter_bd_color'   => '#DCDCDC', //ok
                    'alter_bd_hover'   => '#C8C8C8', //ok
                    'alter_text'       => '#7E8387', //ok +
                    'alter_light'      => '#9D9D9D', //ok
                    'alter_dark'       => '#29273D', //ok +
                    'alter_link'       => '#6237A0', //ok +
                    'alter_hover'      => '#532792', //ok +
                    'alter_link2'      => '#DEACF5', //ok +
                    'alter_hover2'     => '#D597F2', //ok +
                    'alter_link3'      => '#9754CB', //ok +
                    'alter_hover3'     => '#8942C1', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok
                    'extra_bg_hover'   => '#343434', //
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#6237A0', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok
                    'input_bd_hover'   => '#C8C8C8', //ok
                    'input_text'       => '#7E8387', //ok +
                    'input_light'      => '#9D9D9D', //ok
                    'input_dark'       => '#29273D', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#29273D', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),



            // Color scheme: 'blue'
            'blue' => array(
                'title'    => esc_html__( 'Blue', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#F6F6F6', //ok +
                    'bd_color'         => '#DCDCDC', //ok +

                    // Text and links colors
                    'text'             => '#6E6E6E', //ok +
                    'text_light'       => '#9D9D9D', //ok +
                    'text_dark'        => '#1A1A1A', //ok +
                    'text_link'        => '#FFC64B', //ok +
                    'text_hover'       => '#FEBA27', //ok +
                    'text_link2'       => '#689CB2', //ok +
                    'text_hover2'      => '#568DA4', //ok +
                    'text_link3'       => '#555555', //ok +
                    'text_hover3'      => '#4A4A4A', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#FFFFFF', //ok +
                    'alter_bg_hover'   => '#ECECEC', //ok +
                    'alter_bd_color'   => '#DCDCDC', //ok +
                    'alter_bd_hover'   => '#C8C8C8', //ok +
                    'alter_text'       => '#6E6E6E', //ok +
                    'alter_light'      => '#9D9D9D', //ok +
                    'alter_dark'       => '#1A1A1A', //ok +
                    'alter_link'       => '#FFC64B', //ok +
                    'alter_hover'      => '#FEBA27', //ok +
                    'alter_link2'      => '#689CB2', //ok +
                    'alter_hover2'     => '#568DA4', //ok +
                    'alter_link3'      => '#555555', //ok +
                    'alter_hover3'     => '#4A4A4A', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#958F8C', //
                    'extra_dark'       => '#FFFFFF', //ok +
                    'extra_link'       => '#FFC64B', //ok +
                    'extra_hover'      => '#FFFFFF', //ok +
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok +
                    'input_bd_hover'   => '#C8C8C8', //ok +
                    'input_text'       => '#6E6E6E', //ok +
                    'input_light'      => '#9D9D9D', //ok +
                    'input_dark'       => '#1A1A1A', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'dark'
            'blue-dark'    => array(
                'title'    => esc_html__( 'Blue - Dark', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#111111', //ok +
                    'bd_color'         => '#4C4C4C', //ok +

                    // Text and links colors
                    'text'             => '#E1E1E1', //ok +
                    'text_light'       => '#C2C2C2', //ok +
                    'text_dark'        => '#FFFFFF', //ok +
                    'text_link'        => '#FFC64B', //ok +
                    'text_hover'       => '#FEBA27', //ok +
                    'text_link2'       => '#689CB2', //ok +
                    'text_hover2'      => '#568DA4', //ok +
                    'text_link3'       => '#555555', //ok +
                    'text_hover3'      => '#4A4A4A', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#282828', //ok +
                    'alter_bg_hover'   => '#343434', //ok +
                    'alter_bd_color'   => '#4C4C4C', //ok +
                    'alter_bd_hover'   => '#707070', //ok +
                    'alter_text'       => '#E1E1E1', //ok +
                    'alter_light'      => '#C2C2C2', //ok +
                    'alter_dark'       => '#FFFFFF', //ok
                    'alter_link'       => '#FFC64B', //ok +
                    'alter_hover'      => '#FEBA27', //ok +
                    'alter_link2'      => '#689CB2', //ok +
                    'alter_hover2'     => '#568DA4', //ok +
                    'alter_link3'      => '#555555', //ok +
                    'alter_hover3'     => '#4A4A4A', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#4C4C4C', // +
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#C2C2C2', // +
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#FFC64B', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => '#transparent', //ok
                    'input_bg_hover'   => '#transparent', //ok
                    'input_bd_color'   => '#4C4C4C', //ok +
                    'input_bd_hover'   => '#707070', //ok +
                    'input_text'       => '#E1E1E1', //ok +
                    'input_light'      => '#C2C2C2', //ok +
                    'input_dark'       => '#FFFFFF', //ok

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#e36650',
                    'inverse_bd_hover' => '#cb5b47',
                    'inverse_text'     => '#FFFFFF', //ok
                    'inverse_light'    => '#6f6f6f',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#1A1A1A', //ok +

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),

            // Color scheme: 'light'
            'blue-light' => array(
                'title'    => esc_html__( 'Blue - Light', 'mission' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok +
                    'bd_color'         => '#DCDCDC', //ok +

                    // Text and links colors
                    'text'             => '#6E6E6E', //ok +
                    'text_light'       => '#9D9D9D', //ok +
                    'text_dark'        => '#1A1A1A', //ok +
                    'text_link'        => '#FFC64B', //ok +
                    'text_hover'       => '#FEBA27', //ok +
                    'text_link2'       => '#689CB2', //ok +
                    'text_hover2'      => '#568DA4', //ok +
                    'text_link3'       => '#555555', //ok +
                    'text_hover3'      => '#4A4A4A', //ok +

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F6F6F6', //ok +
                    'alter_bg_hover'   => '#ECECEC', //ok +
                    'alter_bd_color'   => '#DCDCDC', //ok +
                    'alter_bd_hover'   => '#C8C8C8', //ok +
                    'alter_text'       => '#6E6E6E', //ok +
                    'alter_light'      => '#9D9D9D', //ok +
                    'alter_dark'       => '#1A1A1A', //ok +
                    'alter_link'       => '#FFC64B', //ok +
                    'alter_hover'      => '#FEBA27', //ok +
                    'alter_link2'      => '#689CB2', //ok +
                    'alter_hover2'     => '#568DA4', //ok +
                    'alter_link3'      => '#555555', //ok +
                    'alter_hover3'     => '#4A4A4A', //ok +

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#1D1D1D', //ok +
                    'extra_bg_hover'   => '#343434', // +
                    'extra_bd_color'   => '#313131',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#E1E1E1', //ok +
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#FFC64B', //ok +
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#80d572',
                    'extra_hover2'     => '#8be77c',
                    'extra_link3'      => '#ddb837',
                    'extra_hover3'     => '#eec432',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DCDCDC', //ok +
                    'input_bd_hover'   => '#C8C8C8', //ok +
                    'input_text'       => '#6E6E6E', //ok +
                    'input_light'      => '#9D9D9D', //ok +
                    'input_dark'       => '#1A1A1A', //ok +

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#1A1A1A', //ok +
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),



		);
		mission_storage_set( 'schemes', $schemes );
		mission_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> mission_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'mission' ),
		//---> 	'description' => __( 'Description of the new color 1', 'mission' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		mission_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
                'alter_dark_015'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.15,
                ),
                'alter_dark_02'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.2,
                ),
                'alter_dark_05'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.5,
                ),
                'alter_dark_08'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.8,
                ),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
                'text_dark_003'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.03,
                ),
                'text_dark_005'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.05,
                ),
                'text_dark_008'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.08,
                ),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
                'text_dark_03'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.3,
                ),
                'text_dark_05'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.5,
                ),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'text_dark_08'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.8,
                ),
                'text_link_007'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.07,
                ),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
                'text_link_03'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.3,
                ),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link2_08'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.8,
                ),
                'text_link2_007'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.07,
                ),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
                'text_link2_03'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.3,
                ),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
                'text_link3_007'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.07,
                ),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
                'text_link3_03'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.3,
                ),
                'inverse_text_03'      => array(
                    'color' => 'inverse_text',
                    'alpha' => 0.3,
                ),
                'inverse_link_08'      => array(
                    'color' => 'inverse_link',
                    'alpha' => 0.8,
                ),
                'inverse_hover_08'      => array(
                    'color' => 'inverse_hover',
                    'alpha' => 0.8,
                ),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		mission_storage_set(
			'schemes_simple', array(
				'text_link'        => array(),
				'text_hover'       => array(),
				'text_link2'       => array(),
				'text_hover2'      => array(),
				'text_link3'       => array(),
				'text_hover3'      => array(),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
			)
		);

		// Parameters to set order of schemes in the css
		mission_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		mission_storage_set(
			'color_presets', array(
				'autumn' => array(
								'title'  => esc_html__( 'Autumn', 'mission' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	),
												'dark' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	)
												)
							),
				'green' => array(
								'title'  => esc_html__( 'Natural Green', 'mission' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	),
												'dark' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	)
												)
							),
			)
		);
	}
}

// Activation methods
if ( ! function_exists( 'mission_skin_filter_activation_methods2' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'mission_skin_filter_activation_methods2', 11, 1 );
    function mission_skin_filter_activation_methods2( $args ) {
        $args['elements_key'] = true;
        return $args;
    }
}
