<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package MISSION
 * @since MISSION 1.0
 */

$mission_template_args = get_query_var( 'mission_template_args' );

if ( is_array( $mission_template_args ) ) {
	$mission_columns    = empty( $mission_template_args['columns'] ) ? 2 : max( 1, $mission_template_args['columns'] );
	$mission_blog_style = array( $mission_template_args['type'], $mission_columns );
    $mission_columns_class = mission_get_column_class( 1, $mission_columns, ! empty( $mission_template_args['columns_tablet']) ? $mission_template_args['columns_tablet'] : '', ! empty($mission_template_args['columns_mobile']) ? $mission_template_args['columns_mobile'] : '' );
} else {
	$mission_template_args = array();
	$mission_blog_style = explode( '_', mission_get_theme_option( 'blog_style' ) );
	$mission_columns    = empty( $mission_blog_style[1] ) ? 2 : max( 1, $mission_blog_style[1] );
    $mission_columns_class = mission_get_column_class( 1, $mission_columns );
}
$mission_expanded   = ! mission_sidebar_present() && mission_get_theme_option( 'expand_content' ) == 'expand';

$mission_post_format = get_post_format();
$mission_post_format = empty( $mission_post_format ) ? 'standard' : str_replace( 'post-format-', '', $mission_post_format );

?><div class="<?php
	if ( ! empty( $mission_template_args['slider'] ) ) {
		echo ' slider-slide swiper-slide';
	} else {
		echo ( mission_is_blog_style_use_masonry( $mission_blog_style[0] ) ? 'masonry_item masonry_item-1_' . esc_attr( $mission_columns ) : esc_attr( $mission_columns_class ) );
	}
?>"><article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
		'post_item post_item_container post_format_' . esc_attr( $mission_post_format )
				. ' post_layout_classic post_layout_classic_' . esc_attr( $mission_columns )
				. ' post_layout_' . esc_attr( $mission_blog_style[0] )
				. ' post_layout_' . esc_attr( $mission_blog_style[0] ) . '_' . esc_attr( $mission_columns )
	);
	mission_add_blog_animation( $mission_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$mission_hover      = ! empty( $mission_template_args['hover'] ) && ! mission_is_inherit( $mission_template_args['hover'] )
							? $mission_template_args['hover']
							: mission_get_theme_option( 'image_hover' );

	$mission_components = ! empty( $mission_template_args['meta_parts'] )
							? ( is_array( $mission_template_args['meta_parts'] )
								? $mission_template_args['meta_parts']
								: explode( ',', $mission_template_args['meta_parts'] )
								)
							: mission_array_get_keys_by_value( mission_get_theme_option( 'meta_parts' ) );

	mission_show_post_featured( apply_filters( 'mission_filter_args_featured',
		array(
			'thumb_size' => ! empty( $mission_template_args['thumb_size'] )
				? $mission_template_args['thumb_size']
				: mission_get_thumb_size(
				'classic' == $mission_blog_style[0]
						? ( strpos( mission_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $mission_columns > 2 ? 'big' : 'huge' )
								: ( $mission_columns > 2
									? ( $mission_expanded ? 'square' : 'square' )
									: ($mission_columns > 1 ? 'square' : ( $mission_expanded ? 'huge' : 'big' ))
									)
							)
						: ( strpos( mission_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $mission_columns > 2 ? 'masonry-big' : 'full' )
								: ($mission_columns === 1 ? ( $mission_expanded ? 'huge' : 'big' ) : ( $mission_columns <= 2 && $mission_expanded ? 'masonry-big' : 'masonry' ))
							)
			),
			'hover'      => $mission_hover,
			'meta_parts' => $mission_components,
			'no_links'   => ! empty( $mission_template_args['no_links'] ),
        ),
        'content-classic',
        $mission_template_args
    ) );

	// Title and post meta
	$mission_show_title = get_the_title() != '';
	$mission_show_meta  = count( $mission_components ) > 0 && ! in_array( $mission_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $mission_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php

			// Post meta
			if ( apply_filters( 'mission_filter_show_blog_meta', $mission_show_meta, $mission_components, 'classic' ) ) {
				if ( count( $mission_components ) > 0 ) {
					do_action( 'mission_action_before_post_meta' );
					mission_show_post_meta(
						apply_filters(
							'mission_filter_post_meta_args', array(
							'components' => join( ',', $mission_components ),
							'seo'        => false,
							'echo'       => true,
						), $mission_blog_style[0], $mission_columns
						)
					);
					do_action( 'mission_action_after_post_meta' );
				}
			}

			// Post title
			if ( apply_filters( 'mission_filter_show_blog_title', true, 'classic' ) ) {
				do_action( 'mission_action_before_post_title' );
				if ( empty( $mission_template_args['no_links'] ) ) {
					the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
				} else {
					the_title( '<h4 class="post_title entry-title">', '</h4>' );
				}
				do_action( 'mission_action_after_post_title' );
			}

			if( !in_array( $mission_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
				// More button
				if ( apply_filters( 'mission_filter_show_blog_readmore', ! $mission_show_title || ! empty( $mission_template_args['more_button'] ), 'classic' ) ) {
					if ( empty( $mission_template_args['no_links'] ) ) {
						do_action( 'mission_action_before_post_readmore' );
						mission_show_post_more_link( $mission_template_args, '<div class="more-wrap">', '</div>' );
						do_action( 'mission_action_after_post_readmore' );
					}
				}
			}
			?>
		</div><!-- .entry-header -->
		<?php
	}

	// Post content
	if( in_array( $mission_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
		ob_start();
		if (apply_filters('mission_filter_show_blog_excerpt', empty($mission_template_args['hide_excerpt']) && mission_get_theme_option('excerpt_length') > 0, 'classic')) {
			mission_show_post_content($mission_template_args, '<div class="post_content_inner">', '</div>');
		}
		// More button
		if(! empty( $mission_template_args['more_button'] )) {
			if ( empty( $mission_template_args['no_links'] ) ) {
				do_action( 'mission_action_before_post_readmore' );
				mission_show_post_more_link( $mission_template_args, '<div class="more-wrap">', '</div>' );
				do_action( 'mission_action_after_post_readmore' );
			}
		}
		$mission_content = ob_get_contents();
		ob_end_clean();
		mission_show_layout($mission_content, '<div class="post_content entry-content">', '</div><!-- .entry-content -->');
	}
	?>

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
